@@ -15,17 +15,18 @@
 #'   \item{lobe.hemi}{Integer vector indicating the lobe and hemisphere}
 #'   \item{circle.layout}{Integer vector for ordering the vertices for circle
 #'     plots}
+#'   \item{x, y, z, x.mni, y.mni, z.mni}{Spatial coordinates}
+#'   \item{color.lobe}{Colors based on \emph{lobe}}
 #' @author Christopher G. Watson, \email{cgwatson@@bu.edu}
 
 assign_lobes <- function(g, rand=FALSE) {
-  lobe <- hemi <- name <- class <- NULL
-  if (!'atlas' %in% graph_attr_names(g)) {
-    stop(sprintf('Input graph %s does not have an "atlas" attribute!',
-                 deparse(substitute(g))))
-  }
-  atlas.dt <- eval(parse(text=g$atlas))
+
+  stopifnot(is_igraph(g))
+  stopifnot('atlas' %in% graph_attr_names(g))
+  lobe <- hemi <- name <- class <- network <- x <- y <- z <- x.mni <- y.mni <- z.mni <- NULL
 
   # Check that vertex names match the atlas names
+  atlas.dt <- eval(parse(text=g$atlas))
   nonmatches <- !V(g)$name %in% atlas.dt[, name]
   if (any(nonmatches)) {
     stop(paste('Check the following vertex names: ',
@@ -37,11 +38,27 @@ assign_lobes <- function(g, rand=FALSE) {
   V(g)$lobe.hemi <- as.numeric(atlas.dt[vorder, interaction(lobe, hemi)])
   V(g)$hemi <- as.character(atlas.dt[vorder, hemi])
 
-  if (g$atlas == 'destrieux') V(g)$class <- atlas.dt[vorder, as.numeric(class)]
+  if (g$atlas %in% c('destrieux', 'destrieux.scgm')) V(g)$class <- atlas.dt[vorder, as.numeric(class)]
+  if (g$atlas == 'dosenbach160') V(g)$network <- atlas.dt[vorder, as.numeric(network)]
 
   if (!isTRUE(rand)) {
+    # Add spatial coordinates for plotting over a brain slice
+    V(g)$x <- V(g)$x.mni <- atlas.dt[vorder, x.mni]
+    V(g)$y <- V(g)$y.mni <- atlas.dt[vorder, y.mni]
+    V(g)$z <- V(g)$z.mni <- atlas.dt[vorder, z.mni]
+    V(g)$color.lobe <- group.cols[V(g)$lobe]
+    E(g)$color.lobe <- color.edges(g, V(g)$lobe)
+    if (g$atlas %in% c('destrieux', 'destrieux.scgm')) {
+      V(g)$color.class <- group.cols[V(g)$class]
+      E(g)$color.class <- color.edges(g, V(g)$class)
+    }
+    if (g$atlas == 'dosenbach160') {
+      V(g)$color.network <- group.cols[V(g)$network]
+      E(g)$color.network <- color.edges(g, V(g)$network)
+    }
+
+    counts <- atlas.dt[order(lobe), .N, by=list(lobe, hemi)]$N
     if (g$atlas %in% c('dkt', 'dk', 'destrieux')) {
-      counts <- atlas.dt[order(lobe), .N, by=list(lobe, hemi)]$N
       V(g)$circle.layout <-
         c(which(V(g)$lobe == 1 & V(g)$hemi == 'L'),
           which(V(g)$lobe == 5 & V(g)$hemi == 'L'),
@@ -56,9 +73,9 @@ assign_lobes <- function(g, rand=FALSE) {
           which(V(g)$lobe == 5 & V(g)$hemi == 'R'),
           which(V(g)$lobe == 1 & V(g)$hemi == 'R'))
 
-    } else if (g$atlas %in% c('aal90', 'lpba40', 'hoa112', 'brainsuite',
-                            'dk.scgm', 'dkt.scgm')) {
-      counts <- atlas.dt[order(lobe), .N, by=list(lobe, hemi)]$N
+    } else if (g$atlas %in% c('aal90', 'aal2.94', 'aal116', 'aal2.120', 'lpba40',
+                              'hoa112', 'brainsuite', 'dk.scgm', 'dkt.scgm',
+                              'destrieux.scgm', 'dosenbach160')) {
       V(g)$circle.layout <-
         c(which(V(g)$lobe == 1 & V(g)$hemi == 'L'),
           which(V(g)$lobe == 5 & V(g)$hemi == 'L'),
@@ -74,6 +91,15 @@ assign_lobes <- function(g, rand=FALSE) {
           which(V(g)$lobe == 6 & V(g)$hemi == 'R'),
           which(V(g)$lobe == 5 & V(g)$hemi == 'R'),
           which(V(g)$lobe == 1 & V(g)$hemi == 'R'))
+      if (g$atlas %in% c('aal116', 'aal2.120', 'dosenbach160')) {
+        mid1 <- sum(counts[seq(1, 14, 2)])
+        mid2 <- sum(counts[seq(1, 15, 2)])
+        V(g)$circle.layout <-
+          c(V(g)$circle.layout[1:mid1],
+            which(V(g)$lobe == 8 & V(g)$hemi == 'L'),
+            V(g)$circle.layout[(mid2+1):(mid2+mid1)],
+            which(V(g)$lobe == 8 & V(g)$hemi == 'R'))
+      }
     }
   }
 
