@@ -10,22 +10,18 @@
 #' @author Christopher G. Watson, \email{cgwatson@@bu.edu}
 
 count_homologous <- function(g) {
-  if (!is.igraph(g)) {
-    stop(sprintf('%s is not a graph object', deparse(substitute(g))))
-  }
-  if (!'atlas' %in% graph_attr_names(g)) {
-    stop(sprintf('Graph "%s" must have an "atlas" attribute',
-                 deparse(substitute(g))))
-  }
+  stopifnot(is_igraph(g))
+  stopifnot('atlas' %in% graph_attr_names(g))
+
   atlas <- g$atlas
   Nv <- vcount(g)
   if (atlas %in% c('dkt', 'dk', 'destrieux', 'brainsuite',
-                   'dk.scgm', 'dkt.scgm')) {
+                   'dk.scgm', 'dkt.scgm', 'destrieux.scgm')) {
     half <- Nv / 2
     regions.l <- V(g)$name[seq_len(half)]
     regions.r <- V(g)$name[(half + 1):Nv]
 
-  } else if (atlas %in% c('aal90', 'hoa112')) {
+  } else if (atlas %in% c('aal90', 'aal116', 'aal2.94', 'aal2.120', 'hoa112')) {
     regions.l <- V(g)$name[seq(1, Nv, by=2)]
     regions.r <- V(g)$name[seq(2, Nv, by=2)]
 
