@@ -27,9 +27,7 @@
 
 robustness <- function(g, type=c('vertex', 'edge'),
                        measure=c('btwn.cent', 'degree', 'random'), N=1e3) {
-  if (!is.igraph(g)) {
-    stop(sprintf('%s is not a graph object', deparse(substitute(g))))
-  }
+  stopifnot(is_igraph(g))
   type <- match.arg(type)
   measure <- match.arg(measure)
   max.comp.orig <- g$max.comp
