@@ -6,8 +6,8 @@
 #' the graph is considered the maximum across all vertices.
 #'
 #' @param g The igraph graph object of interest
-#' @param .parallel Logical indicating whether or not to use \emph{foreach}
-#' (default: TRUE)
+#' @param use.parallel Logical indicating whether or not to use \emph{foreach}
+#'   (default: TRUE)
 #' @param weighted Logical indicating whether weighted efficiency should be
 #' calculated (default: FALSE)
 #' @export
@@ -19,10 +19,8 @@
 #' @references Latora V., Marchiori M. (2005) \emph{Variability and protection
 #' of infrastructure networks}. Physical Review E, 71:015103.
 
-vulnerability <- function(g, .parallel=TRUE, weighted=FALSE) {
-  if (!is.igraph(g)) {
-    stop(sprintf('%s is not a graph object', deparse(substitute(g))))
-  }
+vulnerability <- function(g, use.parallel=TRUE, weighted=FALSE) {
+  stopifnot(is_igraph(g))
   if (isTRUE(weighted)) {
     weights <- NULL
     g.attr <- 'E.global.wt'
@@ -42,7 +40,7 @@ vulnerability <- function(g, .parallel=TRUE, weighted=FALSE) {
   }
   vuln <- rep(0, vcount(g))
   inds <- which(degs > 0)
-  if (isTRUE(.parallel)) {
+  if (isTRUE(use.parallel)) {
     vuln[inds] <- foreach(i=seq_along(inds), .combine='c') %dopar% {
       g.tmp <- delete.vertices(g, inds[i])
       E.global.tmp <- graph.efficiency(g.tmp, 'global', weights)
